

<a id="confluent-flink-artifact-create"></a>

# confluent flink artifact create

## Description

### Cloud

Create a Flink UDF artifact.

```none
confluent flink artifact create <unique-name> [flags]
```

### On-Premises

Create a Flink artifact in Confluent Platform by uploading a JAR or ZIP file. This creates version 1 of the artifact. To use the artifact as a UDF, its name must end in `.jar`.

```none
confluent flink artifact create <name> [flags]
```

## Flags

### Cloud

```none
    --artifact-file string        REQUIRED: Flink artifact JAR file or ZIP file.
    --cloud string                REQUIRED: Specify the cloud provider as "aws", "azure", or "gcp".
    --region string               REQUIRED: Cloud region for Flink (use "confluent flink region list" to see all).
    --environment string          Environment ID.
    --runtime-language string     Specify the Flink artifact runtime language as "python" or "java". (default "java")
    --description string          Specify the Flink artifact description.
    --documentation-link string   Specify the Flink artifact documentation link.
    --context string              CLI context name.
-o, --output string               Specify the output format as "human", "json", or "yaml". (default "human")
```

### On-Premises

```none
    --environment string                  REQUIRED: Name of the Flink environment.
    --artifact-file string                REQUIRED: Path to the Flink artifact JAR or ZIP file.
    --label strings                       A comma-separated list of "key=value" label pairs.
    --url string                          Base URL of the Confluent Manager for Apache Flink (CMF). Environment variable "CONFLUENT_CMF_URL" may be set in place of this flag.
    --client-key-path string              Path to client private key for mTLS authentication. Environment variable "CONFLUENT_CMF_CLIENT_KEY_PATH" may be set in place of this flag.
    --client-cert-path string             Path to client cert to be verified by Confluent Manager for Apache Flink. Include for mTLS authentication. Environment variable "CONFLUENT_CMF_CLIENT_CERT_PATH" may be set in place of this flag.
    --certificate-authority-path string   Path to a PEM-encoded Certificate Authority to verify the Confluent Manager for Apache Flink connection. Environment variable "CONFLUENT_CMF_CERTIFICATE_AUTHORITY_PATH" may be set in place of this flag.
-o, --output string                       Specify the output format as "human", "json", or "yaml". (default "human")
```

## Global Flags

```none
-h, --help            Show help for this command.
    --unsafe-trace    Equivalent to -vvvv, but also log HTTP requests and responses which might contain plaintext secrets.
-v, --verbose count   Increase verbosity (-v for warn, -vv for info, -vvv for debug, and -vvvv for trace).
```

## Examples

### Cloud

Create Flink artifact “my-flink-artifact”.

```none
confluent flink artifact create my-flink-artifact --artifact-file artifact.jar --cloud aws --region us-west-2 --environment env-123456
```

Create Flink artifact “flink-java-artifact”.

```none
confluent flink artifact create my-flink-artifact --artifact-file artifact.jar --cloud aws --region us-west-2 --environment env-123456 --description flinkJavaScalar
```

### On-Premises

Create Flink artifact “my-udf.jar” from the file “my-udf-1.0.jar” in the environment “my-environment”.

```none
confluent flink artifact create my-udf.jar --artifact-file my-udf-1.0.jar --environment my-environment
```

## See Also

* [confluent flink artifact](index.md#confluent-flink-artifact) - Manage Flink UDF artifacts.
